@@ -1,5 +1,7 @@
 from .run_sql_checks import run_dbt_table_diff
+import arg_parser
 
 __all__ = [
     run_dbt_table_diff,
+    arg_parser,
 ]
\ No newline at end of file
